@@ -37,6 +37,3 @@ def example_not_found_hook(introspection_data, **kwargs):
 class ExampleRuleAction(base.RuleActionPlugin):  # pragma: no cover
     def apply(self, node_info, params, **kwargs):
         LOG.debug('apply action to %s: %s', node_info.uuid, params)
-
-    def rollback(self, node_info, params, **kwargs):
-        LOG.debug('rollback action to %s: %s', node_info.uuid, params)
