@@ -13,10 +13,10 @@
 
 import collections
 import time
+from unittest import mock
 
 import fixtures
-from ironicclient import exceptions
-import mock
+from openstack import exceptions as os_exc
 from oslo_config import cfg
 
 from ironic_inspector.common import ironic as ir_utils
@@ -48,8 +48,8 @@ class BaseTest(test_base.NodeTest):
 
     def _prepare(self, client_mock):
         cli = client_mock.return_value
-        cli.node.get.return_value = self.node
-        cli.node.validate.return_value = mock.Mock(power={'result': True})
+        cli.get_node.return_value = self.node
+        cli.validate_node.return_value = mock.Mock(power={'result': True})
         return cli
 
 
@@ -62,22 +62,21 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
-        cli.node.validate.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
+        cli.validate_node.assert_called_once_with(self.uuid, required='power')
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[self.bmc_address],
                                            manage_boot=True,
                                            ironic=cli)
         self.node_info.ports.assert_called_once_with()
-        self.node_info.add_attribute.assert_called_once_with('mac',
-                                                             self.macs)
+        self.node_info.add_attribute.assert_called_once_with(
+            'mac', self.macs)
         self.sync_filter_mock.assert_called_with(cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
-                                                         'pxe',
-                                                         persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_boot_device.assert_called_once_with(
+            self.uuid, 'pxe', persistent=False)
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
@@ -91,8 +90,8 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
-        cli.node.validate.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
+        cli.validate_node.assert_called_once_with(self.uuid, required='power')
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=addresses,
@@ -102,11 +101,11 @@ class TestIntrospect(BaseTest):
         self.node_info.add_attribute.assert_called_once_with('mac',
                                                              self.macs)
         self.sync_filter_mock.assert_called_with(cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
@@ -117,8 +116,8 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
-        cli.node.validate.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
+        cli.validate_node.assert_called_once_with(self.uuid, required='power')
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[],
@@ -128,11 +127,11 @@ class TestIntrospect(BaseTest):
         self.node_info.add_attribute.assert_called_once_with('mac',
                                                              self.macs)
         self.sync_filter_mock.assert_called_with(cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
@@ -151,22 +150,22 @@ class TestIntrospect(BaseTest):
 
     def test_power_failure(self, client_mock, start_mock):
         cli = self._prepare(client_mock)
-        cli.node.set_power_state.side_effect = exceptions.BadRequest()
+        cli.set_node_power_state.side_effect = os_exc.BadRequestException()
         start_mock.return_value = self.node_info
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[self.bmc_address],
                                            manage_boot=True,
                                            ironic=cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         start_mock.return_value.finished.assert_called_once_with(
             introspect.istate.Events.error, error=mock.ANY)
         self.node_info.acquire_lock.assert_called_once_with()
@@ -179,13 +178,13 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[self.bmc_address],
                                            manage_boot=True,
                                            ironic=cli)
-        self.assertFalse(cli.node.set_boot_device.called)
+        self.assertFalse(cli.set_node_boot_device.called)
         start_mock.return_value.finished.assert_called_once_with(
             introspect.istate.Events.error, error=mock.ANY)
         self.node_info.acquire_lock.assert_called_once_with()
@@ -193,21 +192,21 @@ class TestIntrospect(BaseTest):
 
     def test_set_boot_device_failure(self, client_mock, start_mock):
         cli = self._prepare(client_mock)
-        cli.node.set_boot_device.side_effect = exceptions.BadRequest()
+        cli.set_node_boot_device.side_effect = os_exc.BadRequestException()
         start_mock.return_value = self.node_info
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[self.bmc_address],
                                            manage_boot=True,
                                            ironic=cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_not_called()
+        cli.set_node_power_state.assert_not_called()
         start_mock.return_value.finished.assert_called_once_with(
             introspect.istate.Events.error, error=mock.ANY)
         self.node_info.acquire_lock.assert_called_once_with()
@@ -228,11 +227,11 @@ class TestIntrospect(BaseTest):
                                            ironic=cli)
         self.assertFalse(self.node_info.add_attribute.called)
         self.assertFalse(self.sync_filter_mock.called)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
 
     def test_forced_persistent_boot(self, client_mock, start_mock):
         self.node.driver_info['force_persistent_boot_device'] = 'Always'
@@ -241,8 +240,9 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
-        cli.node.validate.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
+        cli.validate_node.assert_called_once_with(self.uuid,
+                                                  required='power')
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[self.bmc_address],
@@ -252,11 +252,11 @@ class TestIntrospect(BaseTest):
         self.node_info.add_attribute.assert_called_once_with('mac',
                                                              self.macs)
         self.sync_filter_mock.assert_called_with(cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=True)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
@@ -267,8 +267,9 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid)
 
-        cli.node.get.assert_called_once_with(self.uuid)
-        cli.node.validate.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
+        cli.validate_node.assert_called_once_with(self.uuid,
+                                                  required='power')
 
         start_mock.assert_called_once_with(self.uuid,
                                            bmc_address=[self.bmc_address],
@@ -278,11 +279,11 @@ class TestIntrospect(BaseTest):
         self.node_info.add_attribute.assert_called_once_with('mac',
                                                              self.macs)
         self.sync_filter_mock.assert_called_with(cli)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=True)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
@@ -298,7 +299,7 @@ class TestIntrospect(BaseTest):
         self.node_info.finished.assert_called_once_with(
             introspect.istate.Events.error, error=mock.ANY)
         self.assertEqual(0, self.sync_filter_mock.call_count)
-        self.assertEqual(0, cli.node.set_power_state.call_count)
+        self.assertEqual(0, cli.set_node_power_state.call_count)
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
@@ -314,52 +315,50 @@ class TestIntrospect(BaseTest):
 
         self.node_info.ports.assert_called_once_with()
         self.assertFalse(self.node_info.finished.called)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
 
     def test_failed_to_get_node(self, client_mock, start_mock):
         cli = client_mock.return_value
-        cli.node.get.side_effect = exceptions.NotFound()
+        cli.get_node.side_effect = os_exc.NotFoundException()
         self.assertRaisesRegex(utils.Error,
                                'Node %s was not found' % self.uuid,
                                introspect.introspect, self.uuid)
 
-        cli.node.get.side_effect = exceptions.BadRequest()
+        cli.get_node.side_effect = os_exc.BadRequestException()
         self.assertRaisesRegex(utils.Error,
-                               '%s: Bad Request' % self.uuid,
+                               'Cannot get node %s: Error' % self.uuid,
                                introspect.introspect, self.uuid)
 
         self.assertEqual(0, self.node_info.ports.call_count)
         self.assertEqual(0, self.sync_filter_mock.call_count)
-        self.assertEqual(0, cli.node.set_power_state.call_count)
+        self.assertEqual(0, cli.set_node_power_state.call_count)
         self.assertFalse(start_mock.called)
         self.assertFalse(self.node_info.acquire_lock.called)
 
     def test_failed_to_validate_node(self, client_mock, start_mock):
         cli = client_mock.return_value
-        cli.node.get.return_value = self.node
-        cli.node.validate.return_value = mock.Mock(power={'result': False,
-                                                          'reason': 'oops'})
-
+        cli.get_node.return_value = self.node
+        cli.validate_node.side_effect = os_exc.ValidationException()
         self.assertRaisesRegex(
             utils.Error,
-            'Failed validation of power interface',
+            'Failed validation of power interface: ValidationException',
             introspect.introspect, self.uuid)
 
-        cli.node.validate.assert_called_once_with(self.uuid)
+        cli.validate_node.assert_called_once_with(self.uuid, required='power')
         self.assertEqual(0, self.node_info.ports.call_count)
         self.assertEqual(0, self.sync_filter_mock.call_count)
-        self.assertEqual(0, cli.node.set_power_state.call_count)
+        self.assertEqual(0, cli.set_node_power_state.call_count)
         self.assertFalse(start_mock.called)
         self.assertFalse(self.node_info.acquire_lock.called)
 
     def test_wrong_provision_state(self, client_mock, start_mock):
         self.node.provision_state = 'active'
         cli = client_mock.return_value
-        cli.node.get.return_value = self.node
+        cli.get_node.return_value = self.node
 
         self.assertRaisesRegex(
             utils.Error, 'Invalid provision state for introspection: "active"',
@@ -367,15 +366,15 @@ class TestIntrospect(BaseTest):
 
         self.assertEqual(0, self.node_info.ports.call_count)
         self.assertEqual(0, self.sync_filter_mock.call_count)
-        self.assertEqual(0, cli.node.set_power_state.call_count)
+        self.assertEqual(0, cli.set_node_power_state.call_count)
         self.assertFalse(start_mock.called)
         self.assertFalse(self.node_info.acquire_lock.called)
 
     def test_inspect_wait_state_allowed(self, client_mock, start_mock):
         self.node.provision_state = 'inspect wait'
         cli = client_mock.return_value
-        cli.node.get.return_value = self.node
-        cli.node.validate.return_value = mock.Mock(power={'result': True})
+        cli.get_node.return_value = self.node
+        cli.validate_node.return_value = mock.Mock(power={'result': True})
 
         introspect.introspect(self.uuid)
 
@@ -393,11 +392,11 @@ class TestIntrospect(BaseTest):
         introspect.introspect(self.uuid)
 
         self.sleep_fixture.mock.assert_called_once_with(8)
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         # updated to the current time.time()
         self.assertEqual(42, introspect._LAST_INTROSPECTION_TIME)
 
@@ -415,11 +414,11 @@ class TestIntrospect(BaseTest):
         introspect.introspect(self.uuid)
 
         self.sleep_fixture.mock().assert_not_called()
-        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+        cli.set_node_boot_device.assert_called_once_with(self.uuid,
                                                          'pxe',
                                                          persistent=False)
-        cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                         'reboot')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'rebooting')
         # updated to the current time.time()
         self.assertEqual(100, introspect._LAST_INTROSPECTION_TIME)
 
@@ -430,7 +429,7 @@ class TestIntrospect(BaseTest):
 
         introspect.introspect(self.node.uuid, manage_boot=False)
 
-        cli.node.get.assert_called_once_with(self.uuid)
+        cli.get_node.assert_called_once_with(self.uuid)
 
         add_mock.assert_called_once_with(self.uuid,
                                          bmc_address=[self.bmc_address],
@@ -440,9 +439,9 @@ class TestIntrospect(BaseTest):
         self.node_info.add_attribute.assert_called_once_with('mac',
                                                              self.macs)
         self.sync_filter_mock.assert_called_with(cli)
-        self.assertFalse(cli.node.validate.called)
-        self.assertFalse(cli.node.set_boot_device.called)
-        self.assertFalse(cli.node.set_power_state.called)
+        self.assertFalse(cli.validate_node.called)
+        self.assertFalse(cli.set_node_boot_device.called)
+        self.assertFalse(cli.set_node_power_state.called)
 
 
 @mock.patch.object(node_cache, 'get_node', autospec=True)
@@ -469,7 +468,8 @@ class TestAbort(BaseTest):
         get_mock.assert_called_once_with(self.uuid, ironic=cli)
         self.node_info.acquire_lock.assert_called_once_with(blocking=False)
         self.sync_filter_mock.assert_called_once_with(cli)
-        cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'power off')
         self.node_info.finished.assert_called_once_with(
             introspect.istate.Events.abort_end, error='Canceled by operator')
         self.node_info.fsm_event.assert_has_calls(self.fsm_calls)
@@ -487,7 +487,7 @@ class TestAbort(BaseTest):
         get_mock.assert_called_once_with(self.uuid, ironic=cli)
         self.node_info.acquire_lock.assert_called_once_with(blocking=False)
         self.sync_filter_mock.assert_called_once_with(cli)
-        self.assertFalse(cli.node.set_power_state.called)
+        self.assertFalse(cli.set_node_power_state.called)
         self.node_info.finished.assert_called_once_with(
             introspect.istate.Events.abort_end, error='Canceled by operator')
         self.node_info.fsm_event.assert_has_calls(self.fsm_calls)
@@ -501,7 +501,7 @@ class TestAbort(BaseTest):
                                introspect.abort, self.uuid)
 
         self.assertEqual(0, self.sync_filter_mock.call_count)
-        self.assertEqual(0, cli.node.set_power_state.call_count)
+        self.assertEqual(0, cli.set_node_power_state.call_count)
         self.assertEqual(0, self.node_info.finished.call_count)
         self.assertEqual(0, self.node_info.fsm_event.call_count)
 
@@ -515,7 +515,7 @@ class TestAbort(BaseTest):
                                'retry later', introspect.abort, self.uuid)
 
         self.assertEqual(0, self.sync_filter_mock.call_count)
-        self.assertEqual(0, cli.node.set_power_state.call_count)
+        self.assertEqual(0, cli.set_node_power_state.call_count)
         self.assertEqual(0, self.node_info.finshed.call_count)
         self.assertEqual(0, self.node_info.fsm_event.call_count)
 
@@ -532,7 +532,8 @@ class TestAbort(BaseTest):
         get_mock.assert_called_once_with(self.uuid, ironic=cli)
         self.node_info.acquire_lock.assert_called_once_with(blocking=False)
         self.sync_filter_mock.assert_called_once_with(cli)
-        cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'power off')
         self.node_info.finished.assert_called_once_with(
             introspect.istate.Events.abort_end, error='Canceled by operator')
         self.node_info.fsm_event.assert_has_calls(self.fsm_calls)
@@ -543,14 +544,15 @@ class TestAbort(BaseTest):
         self.node_info.acquire_lock.return_value = True
         self.node_info.started_at = time.time()
         self.node_info.finished_at = None
-        cli.node.set_power_state.side_effect = Exception('BadaBoom')
+        cli.set_node_power_state.side_effect = Exception('BadaBoom')
 
         introspect.abort(self.uuid)
 
         get_mock.assert_called_once_with(self.uuid, ironic=cli)
         self.node_info.acquire_lock.assert_called_once_with(blocking=False)
         self.sync_filter_mock.assert_called_once_with(cli)
-        cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
+        cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                         'power off')
         self.node_info.finished.assert_called_once_with(
             introspect.istate.Events.abort_end, error='Canceled by operator')
         self.node_info.fsm_event.assert_has_calls(self.fsm_calls)
