@@ -12,10 +12,10 @@
 # limitations under the License.
 
 import json
+from unittest import mock
 
 import fixtures
 from ironic_lib import mdns
-import mock
 import oslo_messaging as messaging
 import tooz
 
@@ -43,7 +43,6 @@ class BaseManagerTest(test_base.NodeTest):
         self.mock__shutting_down.acquire.return_value = True
         self.manager = manager.ConductorManager()
         self.context = {}
-        self.token = None
 
 
 class TestManagerInitHost(BaseManagerTest):
@@ -56,6 +55,8 @@ class TestManagerInitHost(BaseManagerTest):
                                      'validate_processing_hooks')).mock
         self.mock_filter = self.useFixture(fixtures.MockPatchObject(
             manager.pxe_filter, 'driver')).mock.return_value
+        self.mock_periodic = self.useFixture(fixtures.MockPatchObject(
+            manager.periodics, 'periodic')).mock
         self.mock_PeriodicWorker = self.useFixture(fixtures.MockPatchObject(
             manager.periodics, 'PeriodicWorker')).mock
         self.mock_executor = self.useFixture(fixtures.MockPatchObject(
@@ -66,13 +67,27 @@ class TestManagerInitHost(BaseManagerTest):
             manager.sys, 'exit')).mock
 
     def assert_periodics(self):
+        outer_cleanup_decorator_call = mock.call(
+            spacing=CONF.clean_up_period)
+        self.mock_periodic.assert_has_calls([
+            outer_cleanup_decorator_call,
+            mock.call()(manager.periodic_clean_up)])
+
+        inner_decorator = self.mock_periodic.return_value
+        inner_cleanup_decorator_call = mock.call(
+            manager.periodic_clean_up)
+        inner_decorator.assert_has_calls([inner_cleanup_decorator_call])
+
         self.mock_ExistingExecutor.assert_called_once_with(
             self.mock_executor.return_value)
 
         periodic_worker = self.mock_PeriodicWorker.return_value
 
+        periodic_sync = self.mock_filter.get_periodic_sync_task.return_value
+        callables = [(periodic_sync, None, None),
+                     (inner_decorator.return_value, None, None)]
         self.mock_PeriodicWorker.assert_called_once_with(
-            callables=mock.ANY,
+            callables=callables,
             executor_factory=self.mock_ExistingExecutor.return_value,
             on_failure=self.manager._periodics_watchdog)
         self.assertIs(periodic_worker, self.manager._periodics_worker)
@@ -289,21 +304,40 @@ class TestManagerDelHost(BaseManagerTest):
         mock_coordinator.stop.called_once_with()
 
 
+class TestManagerPeriodicWatchDog(BaseManagerTest):
+    def setUp(self):
+        super(TestManagerPeriodicWatchDog, self).setUp()
+        self.mock_get_callable_name = self.useFixture(fixtures.MockPatchObject(
+            manager.reflection, 'get_callable_name')).mock
+        self.mock_spawn = self.useFixture(fixtures.MockPatchObject(
+            manager.eventlet, 'spawn')).mock
+
+    def test__periodics_watchdog(self):
+        error = RuntimeError('Oops!')
+
+        self.manager._periodics_watchdog(
+            callable_=None, activity=None, spacing=None,
+            exc_info=(None, error, None), traceback=None)
+
+        self.mock_get_callable_name.assert_called_once_with(None)
+        self.mock_spawn.assert_called_once_with(self.manager.del_host)
+
+
 class TestManagerIntrospect(BaseManagerTest):
     @mock.patch.object(introspect, 'introspect', autospec=True)
     def test_do_introspect(self, introspect_mock):
-        self.manager.do_introspection(self.context, self.uuid, self.token)
+        self.manager.do_introspection(self.context, self.uuid)
 
-        introspect_mock.assert_called_once_with(self.uuid, token=self.token,
-                                                manage_boot=True)
+        introspect_mock.assert_called_once_with(self.uuid, manage_boot=True,
+                                                token=None)
 
     @mock.patch.object(introspect, 'introspect', autospec=True)
     def test_do_introspect_with_manage_boot(self, introspect_mock):
-        self.manager.do_introspection(self.context, self.uuid, self.token,
-                                      False)
+        self.manager.do_introspection(self.context, self.uuid,
+                                      manage_boot=False)
 
-        introspect_mock.assert_called_once_with(self.uuid, token=self.token,
-                                                manage_boot=False)
+        introspect_mock.assert_called_once_with(self.uuid, manage_boot=False,
+                                                token=None)
 
     @mock.patch.object(introspect, 'introspect', autospec=True)
     def test_introspect_failed(self, introspect_mock):
@@ -311,19 +345,19 @@ class TestManagerIntrospect(BaseManagerTest):
 
         exc = self.assertRaises(messaging.rpc.ExpectedException,
                                 self.manager.do_introspection,
-                                self.context, self.uuid, self.token)
+                                self.context, self.uuid)
 
         self.assertEqual(utils.Error, exc.exc_info[0])
-        introspect_mock.assert_called_once_with(self.uuid, token=None,
-                                                manage_boot=True)
+        introspect_mock.assert_called_once_with(self.uuid, manage_boot=True,
+                                                token=None)
 
 
 class TestManagerAbort(BaseManagerTest):
     @mock.patch.object(introspect, 'abort', autospec=True)
     def test_abort_ok(self, abort_mock):
-        self.manager.do_abort(self.context, self.uuid, self.token)
+        self.manager.do_abort(self.context, self.uuid)
 
-        abort_mock.assert_called_once_with(self.uuid, token=self.token)
+        abort_mock.assert_called_once_with(self.uuid, token=None)
 
     @mock.patch.object(introspect, 'abort', autospec=True)
     def test_abort_node_not_found(self, abort_mock):
@@ -331,7 +365,7 @@ class TestManagerAbort(BaseManagerTest):
 
         exc = self.assertRaises(messaging.rpc.ExpectedException,
                                 self.manager.do_abort,
-                                self.context, self.uuid, self.token)
+                                self.context, self.uuid)
 
         self.assertEqual(utils.Error, exc.exc_info[0])
         abort_mock.assert_called_once_with(self.uuid, token=None)
@@ -343,7 +377,7 @@ class TestManagerAbort(BaseManagerTest):
 
         exc = self.assertRaises(messaging.rpc.ExpectedException,
                                 self.manager.do_abort,
-                                self.context, self.uuid, self.token)
+                                self.context, self.uuid)
 
         self.assertEqual(utils.Error, exc.exc_info[0])
         abort_mock.assert_called_once_with(self.uuid, token=None)
