@@ -11,7 +11,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
+
 from oslo_config import cfg
 from oslo_utils import units
 
@@ -38,7 +39,7 @@ class TestSchedulerHook(test_base.NodeTest):
         ext = base.processing_hooks_manager()['scheduler']
         self.assertIsInstance(ext.obj, std_plugins.SchedulerHook)
 
-    @mock.patch.object(node_cache.NodeInfo, 'patch')
+    @mock.patch.object(node_cache.NodeInfo, 'patch', autospec=True)
     def test_ok(self, mock_patch):
         patch = [
             {'path': '/properties/cpus', 'value': '4', 'op': 'add'},
@@ -49,7 +50,7 @@ class TestSchedulerHook(test_base.NodeTest):
         self.hook.before_update(self.data, self.node_info)
         self.assertCalledWithPatch(patch, mock_patch)
 
-    @mock.patch.object(node_cache.NodeInfo, 'patch')
+    @mock.patch.object(node_cache.NodeInfo, 'patch', autospec=True)
     def test_no_overwrite(self, mock_patch):
         CONF.set_override('overwrite_existing', False, 'processing')
         self.node.properties = {
@@ -63,7 +64,7 @@ class TestSchedulerHook(test_base.NodeTest):
         self.hook.before_update(self.data, self.node_info)
         self.assertCalledWithPatch(patch, mock_patch)
 
-    @mock.patch.object(node_cache.NodeInfo, 'patch')
+    @mock.patch.object(node_cache.NodeInfo, 'patch', autospec=True)
     def test_missing_cpu(self, mock_patch):
         self.data['inventory']['cpu'] = {'count': 'none'}
         patch = [
@@ -73,7 +74,7 @@ class TestSchedulerHook(test_base.NodeTest):
         self.hook.before_update(self.data, self.node_info)
         self.assertCalledWithPatch(patch, mock_patch)
 
-    @mock.patch.object(node_cache.NodeInfo, 'patch')
+    @mock.patch.object(node_cache.NodeInfo, 'patch', autospec=True)
     def test_missing_memory(self, mock_patch):
         # We require physical_mb, not total
         self.data['inventory']['memory'] = {'total': 42}
@@ -85,7 +86,7 @@ class TestSchedulerHook(test_base.NodeTest):
         self.hook.before_update(self.data, self.node_info)
         self.assertCalledWithPatch(patch, mock_patch)
 
-    @mock.patch.object(node_cache.NodeInfo, 'patch')
+    @mock.patch.object(node_cache.NodeInfo, 'patch', autospec=True)
     def test_no_data(self, mock_patch):
         self.data['inventory']['cpu'] = {}
         self.data['inventory']['memory'] = {}
@@ -343,15 +344,15 @@ class TestValidateInterfacesHookBeforeUpdatePXEEnabled(test_base.NodeTest):
         sorted_interfaces = sorted(self.valid_interfaces.values(),
                                    key=lambda i: i['mac'])
         self.existing_ports = [
-            mock.Mock(spec=['address', 'uuid', 'pxe_enabled'],
-                      address=iface['mac'], pxe_enabled=True)
+            mock.Mock(spec=['address', 'uuid', 'is_pxe_enabled'],
+                      address=iface['mac'], is_pxe_enabled=True)
             for iface in sorted_interfaces
         ]
         self.node_info = node_cache.NodeInfo(uuid=self.uuid, started_at=0,
                                              node=self.node,
                                              ports=self.existing_ports)
 
-    def test_fix_pxe_enabled(self, mock_create_ports, mock_patch_port):
+    def test_fix_is_pxe_enabled(self, mock_create_ports, mock_patch_port):
         self.hook.before_update(self.data, self.node_info)
         # Note(milan) there are just 2 self.valid_interfaces, 'eth1' and 'ib0'
         # eth1 is the PXE booting interface and eth1.mac < ib0.mac
